@@ -6,7 +6,7 @@ import itertools
 from cr_features.helper_functions import checkForFeature
 
 
-def computeFreqFeatures(data, featureNames=None, Fs=50):
+def computeFreqFeatures(data, Fs, featureNames=None):
     """ Computes frequency features of the given array. The signal is converted to power spectral density signal and
     features are calculated on that signal
 
@@ -16,9 +16,12 @@ def computeFreqFeatures(data, featureNames=None, Fs=50):
     :return: the calculated features (names of the features are given in array "freqFeatureNames")
     """
     features = {}
-
+    
     ## 3 highest peaks and corresponding freqs
-    f, Pxx_den = welch(data, Fs)  # f: array of sample frequencies, Pxx_den: power spectrum of data
+    if len(data) < 256:
+        f, Pxx_den = welch(data, Fs, nperseg=len(data))  # f: array of sample frequencies, Pxx_den: power spectrum of data
+    else:
+        f, Pxx_den = welch(data, Fs)  # f: array of sample frequencies, Pxx_den: power spectrum of data
 
     # arr.argsort() returns an array of indices of the same shape as arr that that would sort the array
     # arr[arr.argsort()] returns the sorted array arr (if one-dimensional)
